<?php

$title = "Upgrade from easyNews 1.6.2 to 1.7.0";

$paths['script'] = '..';
$paths['designdat']     = $paths['script'] . '/data/design.dat';
$paths['designphp']     = $paths['script'] . '/data/design.php';
$paths['oldcomments']   = $paths['script'] . '/data/kommentare';
$paths['comments']      = $paths['script'] . '/data/comments';
$paths['testtxt']       = $paths['comments'] . '/test.txt';
$paths['versionscript'] = $paths['script'] . '/data/version.php';

require_once($paths['script'] . '/functions.inc.php');
require_once('upgradefunctions.php');
if (file_exists($paths['versionscript'])) {
	include_once($paths['versionscript']);
	$steps = 2;
} else {
	$steps = 3;
}

build_html_head($title);

$step = $_GET['step'];

if (!$step) {
	$step = 0;
	if ($en_version == '1.7.1') {
		$upgradewarning = <<<WARNTEXT

 <font color="red">Important Note: Don't use this, if you're upgrading from easyNews 1.7.0 to 1.7.1</font><br />
 <br />
WARNTEXT;
	} else {
		$upgradewarning = '';
	}
	buildheader('Start');
	echo <<<STARTTEXT
<br />
<br />
<br />
<span class="text">
 Here the necessary upgrades from easyNews 1.6.2 to 1.7.0 will be processed<br />
 <br />$upgradewarning
 Click the link to go to the first step
</span>
<br />
<br />
STARTTEXT;
	buildfooter('Go to the first step ...');
}

if ($step == 1) {
	buildheader('Step 1: Create design.php from design.dat');
	echo <<<STARTSTEP1
<br />
<br />
<br />
<span class="text">Creating design.php from design.dat: <span style="font-weight:normal;">
STARTSTEP1;
	if (@file_exists($paths['designdat'])) {
		if(!@file_exists($paths['designphp'])) {
			$design = trim(file_get_contents($paths['designdat']));
			$design = en_getdata($design, $en_designscheme);
			$design['innerborder'] = 1;
			$design['outerborder'] = 2;
			en_savedesign($paths['designphp']);
			if(!@file_exists($paths['designphp'])) {
				die ('Error: The file ' . $paths['designphp'] . ' could not be written. Please check the permissions of the data-folder');
			} else {
				echo 'Done';
			}
		} else {
			echo 'Error: The file ' . $paths['designphp'] . ' already exists';
		}
	} else {
		echo 'Error: The file ' . $paths['designdat'] . ' does not exist';
	}
	echo <<<ENDSTEP1
<br />
<br />
</span>
</span>
ENDSTEP1;
	buildfooter('Go to the next step ...');
}

if ($step == 2) {
	buildheader('Step 2: Fix comments and move them to the new folder');
	echo '<br />
<br />
<ul>
 <li><b>Testing:</b> ';
	if (!@is_dir($paths['oldcomments'])) {
		die ('Folder with old Comments could not be accessed. Please check, if the folder exists and if if has the correct permissions</li></ul>');
	}
	if (!@is_dir($paths['comments'])) {
		die ('New folder for the comments could not be accessed. Please check, if the folder exists and if if has the correct permissions</li></ul>');
	}

	if (!@fopen($paths['testtxt'], 'w')) {
		die ('Could not write testfile. Please check, if the folder has the correct permissions.</li></ul>');
	} else {
		unlink($paths['testtxt']);
		echo 'Success</li>' . "\n";
	}

	$trans = get_html_translation_table(HTML_ENTITIES);
	$trans = array_flip($trans);

	$d = dir($paths['oldcomments']);
	while($entry = $d->read()) {
		if (preg_match('#\d+\.dat#', $entry)) {
			echo ' <li><b>Processing ' . $entry . ':</b> ';
			if (file_exists($paths['comments'] . '/' . $entry)) die('<b>File exists</b>. It seems, that the script has already been processed</li></ul>');
			$data = file_get_contents($paths['oldcomments'] . '/' . $entry);
			if (trim($data) != '') {
				$data = preg_replace('#<br\s*/?>#i', '<br />', $data); // Fix bad <br />-Tags
				$data = strtr($data, $trans);
				save($paths['comments'] . '/' . $entry, $data);
				echo 'Done</li>' . "\n";
			} else {
				echo 'Empty file has been ignored</li>' . "\n";
			}
		}
	}
	$d->close();

	echo '</ul>
<br />
';
	if ($steps > 2) {
		buildfooter('Go to the next step ...');
	} else {
		echo '<b>Done. It is recommended to delete upgrade.php now</b>';
	}
}

if ($step == 3) {
	buildheader('Step 3: Upgrading the version number');
	$fp = @fopen($paths['versionscript'], 'w');
	if (!$fp) die ('Could not write version-script. Please check, if the data-folder has the correct permissions.');
	$versionscriptdata = '<?php

$en_version = \'1.7.1\';

?' . '>';
	fwrite($fp, $versionscriptdata);
	fclose($fp);
	echo '<br />
<br />
<b>Done. It is recommended to delete upgrade.php now</b>';
}

?>

</body>
</html>
